print("import: 'openpyxl'")
import openpyxl

print("import: 'openpyxl.cell'")
import openpyxl.cell

print("import: 'openpyxl.chart'")
import openpyxl.chart

print("import: 'openpyxl.chartsheet'")
import openpyxl.chartsheet

print("import: 'openpyxl.comments'")
import openpyxl.comments

print("import: 'openpyxl.compat'")
import openpyxl.compat

print("import: 'openpyxl.descriptors'")
import openpyxl.descriptors

print("import: 'openpyxl.drawing'")
import openpyxl.drawing

print("import: 'openpyxl.formatting'")
import openpyxl.formatting

print("import: 'openpyxl.formula'")
import openpyxl.formula

print("import: 'openpyxl.packaging'")
import openpyxl.packaging

print("import: 'openpyxl.reader'")
import openpyxl.reader

print("import: 'openpyxl.styles'")
import openpyxl.styles

print("import: 'openpyxl.utils'")
import openpyxl.utils

print("import: 'openpyxl.workbook'")
import openpyxl.workbook

print("import: 'openpyxl.workbook.external_link'")
import openpyxl.workbook.external_link

print("import: 'openpyxl.worksheet'")
import openpyxl.worksheet

print("import: 'openpyxl.writer'")
import openpyxl.writer

print("import: 'openpyxl.xml'")
import openpyxl.xml

